# CallbackTokenAuthRequest

Abstract class inspired by DRF's own token serializer. Returns a user if valid, None or a message if not.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**email** | **str** |  | [optional] 
**mobile** | **str** |  | [optional] 
**token** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


